@@ -45,10 +45,6 @@ def material_insiders() -> Iterator[bool]:  # noqa: D103
         yield False
 
 
-below_314 = sys.version_info < (3, 14)
-skip_docs_reason = pyprefix("Building docs is not supported on Python 3.14, skipping")
-
-
 @duty
 def changelog(ctx: Context, bump: str = "") -> None:
     """Update the changelog in-place with latest commits.
@@ -73,7 +69,7 @@ def check_quality(ctx: Context) -> None:
     )
 
 
-@duty(skip_if=not below_314, skip_reason=skip_docs_reason)
+@duty(skip_if=sys.version_info[:2] != (3, 12), skip_reason="Docs build only on Python 3.12")
 def check_docs(ctx: Context) -> None:
     """Check if the documentation builds correctly."""
     Path("htmlcov").mkdir(parents=True, exist_ok=True)
@@ -88,6 +84,7 @@ def check_docs(ctx: Context) -> None:
 @duty
 def check_types(ctx: Context) -> None:
     """Check that the code is correctly typed."""
+    os.environ["FORCE_COLOR"] = "1"
     ctx.run(
         tools.mypy(*PY_SRC_LIST, config_file="config/mypy.ini"),
         title=pyprefix("Type-checking"),
@@ -104,7 +101,7 @@ def check_api(ctx: Context, *cli_args: str) -> None:
     )
 
 
-@duty(skip_if=not below_314, skip_reason=skip_docs_reason)
+@duty
 def docs(ctx: Context, *cli_args: str, host: str = "127.0.0.1", port: int = 8000) -> None:
     """Serve the documentation (localhost:8000).
 
@@ -120,7 +117,7 @@ def docs(ctx: Context, *cli_args: str, host: str = "127.0.0.1", port: int = 8000
         )
 
 
-@duty(skip_if=not below_314, skip_reason=skip_docs_reason)
+@duty
 def docs_deploy(ctx: Context, *, force: bool = False) -> None:
     """Deploy the documentation to GitHub pages.
 
